summaryrefslogtreecommitdiff
path: root/src/backend/taler-merchant-httpd_post-orders-ID-abort.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-04-30 21:23:40 +0200
committerChristian Grothoff <christian@grothoff.org>2020-04-30 21:23:40 +0200
commit577e344b018cf186e179edf8fa56101659e25307 (patch)
tree5dec709ed9dbdb48346499d64c41d78a447fc48e /src/backend/taler-merchant-httpd_post-orders-ID-abort.h
parent3f5bc6fa636e278d54f8a17c6f4d4b15cc63608f (diff)
downloadmerchant-577e344b018cf186e179edf8fa56101659e25307.tar.gz
merchant-577e344b018cf186e179edf8fa56101659e25307.tar.bz2
merchant-577e344b018cf186e179edf8fa56101659e25307.zip
work on /pay and /abort processing
Diffstat (limited to 'src/backend/taler-merchant-httpd_post-orders-ID-abort.h')
-rw-r--r--src/backend/taler-merchant-httpd_post-orders-ID-abort.h31
1 files changed, 13 insertions, 18 deletions
diff --git a/src/backend/taler-merchant-httpd_post-orders-ID-abort.h b/src/backend/taler-merchant-httpd_post-orders-ID-abort.h
index 726a27be..77f55bcf 100644
--- a/src/backend/taler-merchant-httpd_post-orders-ID-abort.h
+++ b/src/backend/taler-merchant-httpd_post-orders-ID-abort.h
@@ -1,6 +1,6 @@
/*
This file is part of TALER
- (C) 2014-2017 GNUnet e.V.
+ (C) 2014-2020 Taler Systems SA
TALER is free software; you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free Software
@@ -14,41 +14,36 @@
TALER; see the file COPYING. If not, see <http://www.gnu.org/licenses/>
*/
/**
- * @file backend/taler-merchant-httpd_pay.h
- * @brief headers for /pay handler
+ * @file backend/taler-merchant-httpd_post-orders-ID-abort.h
+ * @brief headers for POST /orders/$ID/abort handler
* @author Marcello Stanisci
+ * @author Christian Grothoff
*/
-#ifndef TALER_EXCHANGE_HTTPD_PAY_H
-#define TALER_EXCHANGE_HTTPD_PAY_H
+#ifndef TALER_EXCHANGE_HTTPD_POST_ORDERS_ID_ABORT_H
+#define TALER_EXCHANGE_HTTPD_POST_ORDERS_ID_ABORT_H
#include <microhttpd.h>
#include "taler-merchant-httpd.h"
/**
* Force all pay contexts to be resumed as we are about
* to shut down MHD.
*/
void
-MH_force_pc_resume (void);
+TMH_force_ac_resume (void);
/**
- * Manage a payment
+ * Abort payment for a claimed order.
*
* @param rh context of the handler
* @param connection the MHD connection to handle
- * @param[in,out] connection_cls the connection's closure (can be updated)
- * @param upload_data upload data
- * @param[in,out] upload_data_size number of bytes (left) in @a upload_data
- * @param mi merchant backend instance, never NULL
+ * @param[in,out] hc context with further information about the request
* @return MHD result code
*/
MHD_RESULT
-MH_handler_pay (struct TMH_RequestHandler *rh,
- struct MHD_Connection *connection,
- void **connection_cls,
- const char *upload_data,
- size_t *upload_data_size,
- struct MerchantInstance *mi);
+TMH_post_orders_ID_abort (const struct TMH_RequestHandler *rh,
+ struct MHD_Connection *connection,
+ struct TMH_HandlerContext *hc);
#endif
@@ -14,41 +14,36 @@
#include "taler-merchant-httpd.h"
/**
- * Force all pay contexts to be resumed as we are about
+ * Force all abort contexts to be resumed as we are about
* to shut down MHD.
*/